@@ -6,11 +6,13 @@ datazen - An environment extension that exposes compilation capabilities.
 import logging
 from typing import List
 
+# third-party
+from vcorelib.dict import merge_dicts
+
 # internal
 from datazen.compile import get_compile_output, str_compile
 from datazen.environment.base import TaskResult
 from datazen.environment.task import TaskEnvironment
-from datazen.parsing import merge_dicts
 from datazen.paths import advance_dict_by_path
 from datazen.targets import resolve_dep_data
 
